@@ -191,8 +191,8 @@ type CacheHeader struct {
 	CacheAtlasSize                uint64         // size of embedded cache atlas
 	DynamicDataOffset             uint64         // VM offset from cache_header* to the location of dyld_cache_dynamic_data_header
 	DynamicDataMaxSize            uint64         // maximum size of space reserved from dynamic data
-	ImageNamesOffset              uint32         // offset to start of image names (right about sub cache info entries) NEW in iOS 18.0 beta1
-	Unknown                       uint32         // NEW in iOS 18.0 beta1 (is 1)
+	TPROMappingOffset             uint32         // file offset to TPRO mappings  NEW in iOS 18.0 beta1 (hi mrmacete :P)
+	TPROMappingCount              uint32         // TPRO mappings count           NEW in iOS 18.0 beta1 (is 1 for now; protects OBJC_RO)
 }
 
 type CacheMappingInfo struct {
@@ -212,6 +212,8 @@ const (
 	DYLD_CACHE_MAPPING_CONST_DATA  CacheMappingFlag = 1 << 2
 	DYLD_CACHE_MAPPING_TEXT_STUBS  CacheMappingFlag = 1 << 3
 	DYLD_CACHE_DYNAMIC_CONFIG_DATA CacheMappingFlag = 1 << 4
+	DYLD_CACHE_MAPPING_UNKNOWN     CacheMappingFlag = 1 << 5
+	DYLD_CACHE_MAPPING_TPRO        CacheMappingFlag = 1 << 6
 )
 
 func (f CacheMappingFlag) IsNone() bool {
@@ -232,6 +234,40 @@ func (f CacheMappingFlag) IsTextStubs() bool {
 func (f CacheMappingFlag) IsConfigData() bool {
 	return (f & DYLD_CACHE_DYNAMIC_CONFIG_DATA) != 0
 }
+func (f CacheMappingFlag) IsUnknown() bool {
+	return (f & DYLD_CACHE_MAPPING_UNKNOWN) != 0
+}
+func (f CacheMappingFlag) IsTPRO() bool {
+	return (f & DYLD_CACHE_MAPPING_TPRO) != 0
+}
+func (f CacheMappingFlag) String() string {
+	var fStr []string
+	if f.IsAuthData() {
+		fStr = append(fStr, "AUTH_DATA")
+	}
+	if f.IsDirtyData() {
+		fStr = append(fStr, "DIRTY_DATA")
+	}
+	if f.IsTPRO() {
+		fStr = append(fStr, "TPRO")
+	}
+	if f.IsConstData() {
+		fStr = append(fStr, "CONST_DATA")
+	}
+	if f.IsTextStubs() {
+		fStr = append(fStr, "TEXT_STUBS")
+	}
+	if f.IsConfigData() {
+		fStr = append(fStr, "CONFIG_DATA")
+	}
+	if f.IsUnknown() {
+		fStr = append(fStr, "UNKNOWN")
+	}
+	if len(fStr) > 0 {
+		return strings.Join(fStr, " | ")
+	}
+	return ""
+}
 
 type CacheMappingAndSlideInfo struct {
 	Address         uint64             `json:"address,omitempty"`
@@ -551,8 +587,6 @@ func (i CacheSlideInfo5) GetPageSize() uint32 {
 func (i CacheSlideInfo5) SlidePointer(ptr uint64) uint64 {
 	if ptr == 0 {
 		return 0
-	} else if (ptr & 0xFFF0_0000_0000_0000) == 0 {
-		return ptr
 	}
 	pointer := CacheSlidePointer5(ptr)
 	if pointer.Authenticated() {
@@ -1159,6 +1193,11 @@ type subcacheEntry struct {
 	FileSuffix    [32]byte
 }
 
+type TPROMapping struct {
+	Addr uint64
+	Size uint64
+}
+
 // This struct is a small piece of dynamic data that can be included in the shared region, and contains configuration
 // data about the shared cache in use by the process. It is located
 type CacheDynamicDataHeader struct {
